package org.atemsource.atem.api.infrastructure.bean;

/**
 * A reference to a component in the dependency injection container. 
 * @param <T>
 *            the generic type
 * @author sven
 */
public interface Bean<T> {

	/**
	 * Exists in scope.
	 * 
	 * @return true, if the instance exists in the configured scope, false
	 *         otherwise
	 */
	public boolean existsInScope();

	/**
	 * Gets the.
	 * 
	 * @return the instance of this bean, creating it, if it does not exists
	 */
	public T get();

	/**
	 * Gets the bean class.
	 * 
	 * @return the bean class
	 */
	public Class<T> getBeanClass();

	/**
	 * Gets the bean name.
	 * 
	 * @return the bean name
	 */
	public String getBeanName();

	/**
	 * Checks if is scoped target. Scoped targets are wrapped by proxies. Be careful when using reflection on proxies. In spring proxied components are also available without the proxy. TODO : can we hide these specialties?
	 * 
	 * @return true, if is scoped target
	 */
	public boolean isScopedTarget();

	/**
	 * Removes the.
	 */
	public void remove();

}
